# -*- coding: utf-8 -*-

from django import forms
from django.utils.translation import ugettext as _
from django.core.urlresolvers import reverse

from models import BaseMeeting, TeamMeeting
from common.forms import RenderableMixin

import pytz


class BaseMeetingForm(forms.ModelForm, RenderableMixin):
    """ 
    a form to create/update a BaseMeeting
    """
    class Meta:
        model = BaseMeeting
        exclude = ('date_created')

    class Media:
        css = {'all': (
                       '/media/jquery-ui/css/css/smoothness/jquery-ui.css',
                       '/media/jquery-ui-timepicker/css/ui-lightness/ui.timepickr.css',
                       '/media/css/colortip-1.0-jquery.css', 
                       )}
        js = (
              '/media/jquery/jquery.js',
              '/media/jquery-ui/jquery-ui.js',
              '/media/jquery-ui-timepicker/js/jquery.timepickr.min.js',
              '/media/jquery-ui-timepicker/js/ui.timepickr.min.js',
              '/media/js/events-ui.js',
              '/media/js/colortip-1.0-jquery.js',
              )
        
    def __init__(self, *args, **kargs):
        super(BaseMeetingForm, self).__init__(*args, **kargs)
        self.fields['date_begin'].widget = forms.SplitDateTimeWidget()
        self.fields['date_end'].widget = forms.SplitDateTimeWidget()
        
    def clean(self):
        begin = self.cleaned_data.get('date_begin')
        end = self.cleaned_data.get('date_end')
        if begin and end and begin > end:
            raise forms.ValidationError("Meetings can not end before they start.")
        return self.cleaned_data

class TeamMeetingForm(BaseMeetingForm):
    """ 
    a form to create/update a TeamMeeting
    """
    class Meta(BaseMeetingForm.Meta):
        model = TeamMeeting
        exclude = ('teams', 'date_created')
