from django.utils.translation import ugettext

from events.models import TeamEvent

def merge_teams(old_team, new_team):
    msgs = []
    related_events = TeamEvent.objects.filter(teams__id=old_team.id)
    for event in related_events:
        for team in event.teams.filter(id=old_team.id):
            msgs += [ugettext('New owner of event "%(event)" is team "%(team)".' % (event.name, new_team.name))]
            event.teams.remove(team)
            event.teams.add(new_team)
        event.save()
    if old_team.contact_profiles.count() and not new_team.contact_profiles.count():
        for contact_profile in old_team.contact_profiles.all():
            new_team.contact_profiles.add(contact_profile)
            msgs += [ugettext('Adding contact "%(contact)" to team "%(team)".' % (contact_profile.realname, new_team.name))]
    if old_team.countries.count() and not new_team.countries.count():
        for country in old_team.countries.all():
            new_team.countries.add(country)
            msgs += [ugettext('Adding country "%(country)" to team "%(team)".' % (country.name, new_team.name))]
    if old_team.languages.count() and not new_team.languages.count():
        for language in old_team.languages.all():
            new_team.languages.add(language)
            msgs += [ugettext('Adding language "%(language)" to team "%(team)".' % (language.name, new_team.name))]
    if old_team.spr and not new_team.spr:
        new_team.spr = old_team.spr
        msgs += [ugettext('Setting State/Province/Region of "%(team)" to "%(region)".' % (new_team.name, old_team.spr))]
    if old_team.city and not new_team.city:
        new_team.city = old_team.city
        msgs += [ugettext('Setting city of "%(team)" to "%(city)".' % (new_team.name, old_team.city))]
    if old_team.wiki_url and not new_team.wiki_url:
        new_team.wiki_url = old_team.wiki_url
        msgs += [ugettext('Setting Wiki URL of "%(team)" to "%(url)".' % (new_team.name, old_team.wiki_url))]
    if old_team.web_url and not new_team.web_url:
        new_team.web_url = old_team.web_url
        msgs += [ugettext('Setting Web URL of "%(team)" to "%(url)".' % (new_team.name, old_team.web_url))]
    if old_team.ml_url and not new_team.ml_url:
        new_team.ml_url = old_team.ml_url
        msgs += [ugettext('Setting Mailing list URL of "%(team)" to "%(url)".' % (new_team.name, old_team.ml_url))]
    if old_team.forum_url and not new_team.forum_url:
        new_team.forum_url = old_team.forum_url
        msgs += [ugettext('Setting Forum URL of "%(team)" to "%(url)".' % (new_team.name, old_team.forum_url))]
    if old_team.email and not new_team.email:
        new_team.email = old_team.email
        msgs += [ugettext('Setting email address of "%(team)" to "%(email)".' % (new_team.name, old_team.email))]
    if old_team.irc_chan and not new_team.irc_chan:
        new_team.irc_chane = old_team.irc_chan
        msgs += [ugettext('Setting IRC channel of "%(team)" to "%(channel)".' % (new_team.name, old_team.irc_chan))]
    if old_team.flickr_id and not new_team.flickr_id:
        new_team.flickr_id = old_team.flickr_id
        msgs += [ugettext('Setting Flickr ID of "%(team)" to "%(id)".' % (new_team.name, old_team.flickr_id))]
    if old_team.picasa_id and not new_team.picasa_id:
        new_team.picasa_id = old_team.picasa_id
        msgs += [ugettext('Setting Picasa ID of "%(team)" to "%(id)".' % (new_team.name, old_team.picasa_id))]
    if old_team.pixie_id and not new_team.pixie_id:
        new_team.pixie_id = old_team.pixie_id
        msgs += [ugettext('Setting Pix.ie ID of "%(team)" to "%(id)".' % (new_team.name, old_team.pixie_id))]
    new_team.save()
    old_team.delete()
    msgs += [ugettext('Team "%(old_team)" merged with "%(new-team)".' % (old_team.name, new_team.name))]
    return msgs

