# -*- coding: utf-8 -*-

from django import forms
from django.utils.translation import ugettext_lazy as _
from models import Venue

from common.forms import RenderableMixin
from django.conf import settings

try:
    google_api_key = settings.GOOGLE_API_KEY
except AttributeError:
    google_api_key = ""

def validate_name(name):
    if not name or not name.strip():
        raise forms.ValidationError(_(u'Please use a descriptive name for the venue.'))
    return name

class VenueForm(forms.ModelForm, RenderableMixin):
    """ 
    a form to create/update a new Venue
    """
    class Meta:
        model = Venue

    class Media:
        css = {'all': (
                       '/media/css/colortip-1.0-jquery.css', 
                       )}
        js = (
              'http://openlayers.org/api/OpenLayers.js',
              'http://maps.google.com/maps?file=api&amp;v=2&amp;key='+google_api_key ,
              'http://www.openstreetmap.org/openlayers/OpenStreetMap.js',
              '/media/js/common.js',
              '/media/js/colortip-1.0-jquery.js',
              )

    def clean(self):
        self.cleaned_data['name'] = validate_name(self.cleaned_data.get('name'))
        return super(VenueForm, self).clean()


